#
# spec file for package python-opentelemetry-instrumentation-asgi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-instrumentation-asgi%{?psuffix}
Version:        0.54b1
Release:        1.1
Summary:        ASGI instrumentation for OpenTelemetry
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python-contrib/tree/main/instrumentation/opentelemetry-instrumentation-asgi
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry_instrumentation_asgi/opentelemetry_instrumentation_asgi-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module opentelemetry-api >= 1.12}
BuildRequires:  %{python_module opentelemetry-instrumentation = %{version}}
BuildRequires:  %{python_module opentelemetry-semantic-conventions = %{version}}
BuildRequires:  %{python_module opentelemetry-test-utils = %{version}}
BuildRequires:  %{python_module opentelemetry-util-http = %{version}}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-asgiref >= 3.0
Requires:       python-opentelemetry-api >= 1.12
Requires:       python-opentelemetry-instrumentation = %{version}
Requires:       python-opentelemetry-semantic-conventions = %{version}
Requires:       python-opentelemetry-util-http = %{version}
BuildArch:      noarch
%python_subpackages

%description
This library provides a ASGI middleware that can be used on any ASGI framework
(such as Django, Starlette, FastAPI or Quart) to track requests timing through
OpenTelemetry.

%prep
%setup -q -n opentelemetry_instrumentation_asgi-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/opentelemetry/instrumentation/asgi
%{python_sitelib}/opentelemetry_instrumentation_asgi-%{version}.dist-info

%changelog
* Mon Jun  2 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.54b1:
  * Bump for opentelemetry 1.33.1 release.
- Remove unneeded BuildRequires on setuptools and wheel.
* Tue Feb 25 2025 Dirk Müller <dmueller@suse.com>
- update to 0.51b0:
  * bump for opentelemetry 1.30.0 release
* Wed Jan  8 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.50b0
  * `opentelemetry-instrumentation-starlette` Add type hints to the instrumentation
  * `opentelemetry-distro` default to OTLP log exporter.
  * `opentelemetry-instrumentation-sqlalchemy` Update unit tests to run with SQLALchemy 2
  * Add `opentelemetry-instrumentation-openai-v2` to `opentelemetry-bootstrap`
  * `opentelemetry-instrumentation-sqlalchemy` Add sqlcomment to `db.statement` attribute
  * `opentelemetry-instrumentation-dbapi` Add sqlcomment to `db.statement` attribute
  * `opentelemetry-instrumentation-dbapi` instrument_connection accepts optional connect_module
  * `opentelemetry-instrumentation-mysqlclient` Add sqlcommenter support
  * `opentelemetry-instrumentation-pymysql` Add sqlcommenter support
  * `opentelemetry-instrumentation-click`: new instrumentation to trace click commands
  * `opentelemetry-instrumentation-starlette`: Retrieve `meter_provider` key instead of
    `_meter_provider` on `_instrument`
  * `opentelemetry-instrumentation-httpx`: instrument_client is a static method again
  * `opentelemetry-instrumentation-system_metrics`: fix callbacks reading wrong config
  * `opentelemetry-instrumentation-httpx`: Check if mount transport is none before wrap it
  * Replace all instrumentor unit test `assertEqualSpanInstrumentationInfo` calls with
    `assertEqualSpanInstrumentationScope` calls
  * `opentelemetry-instrumentation-sqlalchemy` Fixes engines from `sqlalchemy.engine_from_config`
    not being fully instrumented
  * `opentelemetry-instrumentation-sqlalchemy`: Fix a remaining memory leak in EngineTracer
  * `opentelemetry-instrumentation-sqlite3`: Update documentation on explicit cursor support of tracing
  * `opentelemetry-instrumentation-sqlalchemy` teach instruments version
  * Drop `opentelemetry-instrumentation-test` package from default instrumentation list
  * `opentelemetry-instrumentation-httpx`: remove private unused `_InstrumentedClient`
    and `_InstrumentedAsyncClient` classes
- from version 0.49b0
  * `opentelemetry-instrumentation-openai-v2` Instrumentation for OpenAI >= 0.27.0
  * `opentelemetry-instrumentation-fastapi` Add autoinstrumentation mechanism tests.
  * `opentelemetry-instrumentation-aiokafka` Add instrumentor and auto instrumentation
    support for aiokafka
  * `opentelemetry-instrumentation-redis` Add additional attributes for methods create_index
    and search, rename those spans
  * `opentelemetry-instrumentation` Add support for string based dotted module paths in unwrap
  * `opentelemetry-instrumentation-aiokafka` Wrap `AIOKafkaConsumer.getone()` instead of `AIOKafkaConsumer.__anext__`
  * `opentelemetry-instrumentation-confluent-kafka` Fix to allow `topic` to be extracted from `kwargs` in `produce()`
  * `opentelemetry-instrumentation-system-metrics` Update metric units to conform to UCUM conventions.
  * `opentelemetry-instrumentation-celery` Don't detach context without a None token
  * `opentelemetry-exporter-prometheus-remote-write`: sort labels before exporting
  * `opentelemetry-instrumentation-dbapi` sqlcommenter key values created from PostgreSQL, MySQL systems
  * `opentelemetry-instrumentation-system-metrics`: don't report open file descriptors on Windows
  * Deprecation of pkg_resource in favor of importlib.metadata
  * `opentelemetry-instrumentation` Don't fail distro loading if instrumentor raises ImportError, instead skip them
  * `opentelemetry-instrumentation-httpx` Rewrote instrumentation to use wrapt instead of subclassing
- Use %%{version} in BuildRequires and Requires for dependencies
* Wed Sep  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  * Version 0.48b0
